Introduction
============

This package provides an alternative full view for Plone with support for
BrowserViews. BrowserViews weren't fully supported in the skin layer based
folder_full_view Page Template. This package provides a @@full_view view.

This package fixes: "Error when view folder with folder_full_view view"
http://code.google.com/p/dexterity/issues/detail?id=172

Author
======

Johannes Raggam, BlueDynamics Alliance <raggam-nl [at] adm [dot] at>
